# puppet-opendeploy

[![travis-cs status](https://travis-ci.org/wafture/puppet-opendeploy.svg "travis-ci status")](https://travis-ci.org/wafture/puppet-opendeploy)

#### Table of Contents

1. [Module Description - What the module does and why it is useful](#module-description)
2. [Setup - The basics of getting started with opendeploy](#setup)
    * [Beginning with opendeploy](#beginning-with-opendeploy)
3. [Usage - Configuration options and additional functionality](#usage)
    * [Create a base server](#create-a-base-server)
    * [Create a receiver server](#create-a-receiver-server)
4. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
5. [Limitations - OS compatibility, etc.](#limitations)
6. [Development - Guide for contributing to the module](#development)

## Module Description

The opendeploy module installs, configures, and manages the OpenDeploy service
for each respective run mode.

This module manages the installation of OpenDeploy.

## Setup

### Beginning with opendeploy

To install a base server with the default options:

```puppet
class { '::opendeploy::base':
  source_url =>
  'http://example.com/path/to/IWOVOpenDeployBaseServer.Linux.8.1.0.tar.gz',
}
```

To customize options, such as the install directory or to enable event reporting,
you must also pass the appropriate parameters:

```puppet
class { '::opendeploy::base':
  source_url             =>
  'http://example.com/path/to/IWOVOpenDeployBaseServer.Linux.8.1.0.tar.gz',
  install_dir            => '/usr/od-home',
  enable_event_reporting => 'y',
}
```

Note: when working with any of the modes, the source_url paramter _is_
required. This should be the location to the tarball provided by the vendor.

## Usage

Interaction for each of the server run modes is done via `opendeploy::<MODE>`.
To install the receiver, use `opendeploy::receiver`. To install an admin, use `opendeploy::admin`.

### Create a Base server

To create a base server with custom port mappings:

```puppet
class { '::opendeploy::base':
  source_url     =>
  'http://example.com/path/to/IWOVOpenDeployBaseServer.Linux.8.1.0.tar.gz',
  registry_port  => 9175,
  listening_port => 20015,
}
```

### Create a Receiver server

To create a receiver server with custom port mappings:

```puppet
class { '::opendeploy::receiver':
  source_url     =>
  'http://example.com/path/to/IWOVOpenDeployRcvrServer.Linux.8.1.0.tar.gz',
  registry_port  => 9175,
  listening_port => 20015,
}
```

## Reference

### Classes

#### Public classes

* [`opendeploy::base`](#opendeploybase): Installs and configures OpenDeploy
  Base.
* [`opendeploy::receiver`](#opendeployrcvr): Installs and configures OpenDeploy
  Receiver.

#### Private classes

* `opendeploy::base::install`: Installs OpenDeploy Base.
* `opendeploy::base::service`: Manages service.
* `opendeploy::base::packages`: Installs package dependencies for OpenDeploy.
* `opendeploy::base::skeleton`: Creates appropriate directories for
  installation.
* `opendeploy::receiver::install`: Installs OpenDeploy Receiver.
* `opendeploy::receiver::service`: Manages service.
* `opendeploy::receiver::packages`: Installs package dependencies for OpenDeploy.
* `opendeploy::receiver::skeleton`: Creates appropriate directories for
  installation.

### Parameters

#### opendeploy::base

##### `source_url`

HTTP GETable location of the vendor install tarball.

This is a required parameter.

#####  `install_dir`

Location, as a fully qualified path, on the filesystem to install OpenDeploy.

Using `install_dir => '/opt/od-home'` will create the following structure:
```
/opt/od-home
	├── OpenDeployNG/
		└── <installed files>
	└── odinstall/
		└── <files used to install>
```

Valid values are valid system paths. Defaults to `/opt/od-home`.

#####  `service_ensure`

The status of the service. Valid values are `stopped` and `running`. Defaults
to `running`.

##### `registry_port`

Defines a custom registry port for OpenDeploy to run on. Valid values are
integers. Defaults to `9173`.

##### `listening_port`

Defines a custom registry port for OpenDeploy to run on. Valid values are
integers. Defaults to `20014`.


##### `enable_event_reporting`

Enables event reporting with the OpenDeploy instance. Valid values are `y` or
`n`. Default is `n`.

#### opendeploy::receiver

##### `source_url`

HTTP GETable location of the vendor install tarball.

This is a required parameter.

#####  `install_dir`

Location, as a fully qualified path, on the filesystem to install OpenDeploy.

Using `install_dir => '/opt/od-home'` will create the following structure:
```
/opt/od-home
	├── OpenDeployNG/
		└── <installed files>
	└── odinstall/
		└── <files used to install>
```

Valid values are valid system paths. Defaults to `/opt/od-home`.

#####  `service_ensure`

The status of the service. Valid values are `stopped` and `running`. Defaults
to `running`.

##### `registry_port`

Defines a custom registry port for OpenDeploy to run on. Valid values are
integers. Defaults to `9173`.

##### `listening_port`

Defines a custom registry port for OpenDeploy to run on. Valid values are
integers. Defaults to `20014`.


##### `enable_event_reporting`

Enables event reporting with the OpenDeploy instance. Valid values are `y` or
`n`. Default is `n`.

## Limitations

This module has been tested on:

* RedHat Enterprise Linux 6, 7
* CentOS 6, 7

Testing on other platforms is nonsensical as the vendor only supports the above
systems

## Development

See something you want to improve? Fork, clone, work, commit, and PR. Yay OSS!

### Authors

This module was created and maintained by Nick Anderson.
