require 'spec_helper'

RSpec.describe 'opendeploy::receiver' do

  let(:facts) { {:operatingsystemmajrelease => '7'} }
  let(:params){{:source_url => 'http://bit.ly/odrcvr.tar.gz'}}

  # basics
  describe 'basics' do
  	# compile
    it { should compile.with_all_deps }

	# classes
	it { should contain_class('opendeploy::receiver') }
    it { should contain_class('opendeploy::receiver::params') }
    it { should contain_class('opendeploy::receiver::install') }
    it { should contain_class('opendeploy::receiver::packages') }
    it { should contain_class('opendeploy::receiver::skeleton') }
    it { should contain_class('opendeploy::receiver::service') }

	# files
	it { should contain_file('/etc/init.d/iwodstatus') }

	# packages
	it { should contain_package('nmap-ncat') }
	it { should contain_package('libstdc++.i686') }
	it { should contain_package('openssl098e.i686') }
	it { should contain_package('compat-libstdc++-33.i686') }

	# execs
	it { should contain_exec('download_vendor_tarball') }
	it { should contain_exec('install_opendeploy_receiver') }

	# service
	it { should contain_service('iwodserver') }
  end

  # status package (per os)
  describe 'os_major_6' do
  	let(:facts) { {:operatingsystemmajrelease => '6'} }
	it { should contain_package('nc') }
  end

  # registry_port param
  describe 'default_registry_port' do
    it { should contain_class('opendeploy::receiver').with( 'registry_port' => 9173, ) }
  end
  describe 'user_set_registry_port' do
    let(:params){{:source_url => 'http://bit.ly/odrcvr.tar.gz', :registry_port => 9175}}
    it { should contain_class('opendeploy::receiver').with( 'registry_port' => 9175, ) }
  end

  # listening_port param
  describe 'default_registry_port' do
    it { should contain_class('opendeploy::receiver').with( 'listening_port' => 20014, ) }
  end
  describe 'user_set_registry_port' do
    let(:params){{:source_url => 'http://bit.ly/odrcvr.tar.gz', :listening_port => 20015}}
    it { should contain_class('opendeploy::receiver').with( 'listening_port' => 20015, ) }
  end

  # service_ensure param
  describe 'default_service_ensure' do
    it { should contain_class('opendeploy::receiver').with( 'service_ensure' => 'running', ) }
  end
  describe 'user_set_service_ensure' do
    let(:params){{:source_url => 'http://bit.ly/odrcvr.tar.gz', :service_ensure => 'stopped'}}
    it { should contain_class('opendeploy::receiver').with( 'service_ensure' => 'stopped', ) }
  end

  # install_dir param
  describe 'default_install_dir' do
    it { should contain_file('/opt/od-home') }
    it { should contain_file('/opt/od-home/odinstall') }
    it { should contain_class('opendeploy::receiver').with( 'install_dir' => '/opt/od-home', ) }
  end
  describe 'user_set_install_dir' do
    let(:params){{:source_url => 'http://bit.ly/odrcvr.tar.gz', :install_dir => '/usr/od-home'}}
    it { should contain_file('/usr/od-home') }
    it { should contain_file('/usr/od-home/odinstall') }
    it { should contain_class('opendeploy::receiver').with( 'install_dir' => '/usr/od-home', ) }
  end

  # enable_event_reporting param
  describe 'default_enable_event_reporting' do
    it { should contain_class('opendeploy::receiver').with( 'enable_event_reporting' => 'n', ) }
  end
  describe 'user_set_enable_event_reporting' do
    let(:params){{:source_url => 'http://bit.ly/odrcvr.tar.gz', :enable_event_reporting => 'y'}}
    it { should contain_class('opendeploy::receiver').with( 'enable_event_reporting' => 'y', ) }
  end

end
